@@ -28,7 +28,8 @@ __________         __________           .___              __     ____  __.__  __
                     +-+-+-+-+-+-+-+ +-+-+ +-+-+-+-+-+-+-+-+-+
             
     https://github.com/brootware
-    https://brootware.github.io                                                                             
+    https://brootware.github.io     
+    https://twitter.com/brootware                                                                        
     """
 
 help_menu = """
@@ -118,12 +119,14 @@ def execute_file_arg() -> None:
             full_paths += glob.glob(path + '/*')
 
     for file in files:
-        if args.customfile:
+        if args.customfile and args.dirout:
+            redact_obj.process_custom_file(file, args.customfile, args.dirout)
+            redact_obj.process_report(file)
+        elif args.customfile:
             redact_obj.process_custom_file(file, args.customfile)
             redact_obj.process_report(file)
         elif args.dirout:
             redact_obj.process_core_file(file, args.dirout)
-            redact_obj.process_custom_file(file, args.custom, args.dirout)
             redact_obj.process_report(file, args.dirout)
         elif args.unredact:
             unredact_obj.unredact(file, args.unredact)
